package com.ruoyi.ss.mchApply.service;

import com.ruoyi.ss.mchApply.domain.MchApply;
import com.ruoyi.ss.mchApply.domain.MchApplyQuery;
import com.ruoyi.ss.mchApply.domain.MchApplyVO;

import java.util.List;

/**
 * 商家合作申请Service接口
 *
 * @author ruoyi
 * @date 2024-04-28
 */
public interface IMchApplyService
{
    /**
     * 查询商家合作申请
     *
     * @param applyId 商家合作申请主键
     * @return 商家合作申请
     */
    public MchApplyVO selectMchApplyByApplyId(Long applyId);

    /**
     * 查询商家合作申请列表
     *
     * @param mchApply 商家合作申请
     * @return 商家合作申请集合
     */
    public List<MchApplyVO> selectMchApplyList(MchApplyQuery mchApply);

    /**
     * 新增商家合作申请
     *
     * @param mchApply 商家合作申请
     * @return 结果
     */
    public int insertMchApply(MchApply mchApply);

    /**
     * 修改商家合作申请
     *
     * @param mchApply 商家合作申请
     * @return 结果
     */
    public int updateMchApply(MchApply mchApply);

    /**
     * 批量删除商家合作申请
     *
     * @param applyIds 需要删除的商家合作申请主键集合
     * @return 结果
     */
    public int deleteMchApplyByApplyIds(Long[] applyIds);

    /**
     * 删除商家合作申请信息
     *
     * @param applyId 商家合作申请主键
     * @return 结果
     */
    public int deleteMchApplyByApplyId(Long applyId);

    /**
     * 审核
     * @param applyId 申请id
     * @param pass 是否通过
     * @param remark 审核意见
     */
    boolean verify(Long applyId, Boolean pass, String remark);

    /**
     * 查询数量
     * @param query 查询条件
     * @return 数量
     */
    int selectCount(MchApplyQuery query);

}
